Index: issm/trunk-jpl/src/m/parameterization/setflowequation.js
===================================================================
--- issm/trunk-jpl/src/m/parameterization/setflowequation.js	(revision 25609)
+++ issm/trunk-jpl/src/m/parameterization/setflowequation.js	(revision 27031)
@@ -3,5 +3,5 @@
 //
 //   This routine works like plotmodel: it works with an even number of inputs
 //   'SIA','SSA','L1L2','MLHO','HO','FS' and 'fill' are the possible options
 //   that must be followed by the corresponding exp file or flags list
 //   It can either be a domain file (argus type, .exp extension), or an array of element flags. 
@@ -11,5 +11,5 @@
 //   a string 'all' will be considered as the entire domain
 //   You can specify the type of coupling, 'penalties' or 'tiling', to use with the input 'coupling'
 //   NB: L1L2 and MLHO cannot currently be coupled to any other ice flow model
 //
 //   Usage:
@@ -38,5 +38,5 @@
 	HOflag   = FlagElements(md,options.getfieldvalue('HO',''));
 	L1L2flag = FlagElements(md,options.getfieldvalue('L1L2',''));
-	MLHOflag = FlagElements(md,options.getfieldvalue('MLHO',''));
+	MOLHOflag = FlagElements(md,options.getfieldvalue('MOLHO',''));
 	FSflag   = FlagElements(md,options.getfieldvalue('FS',''));
 	filltype = options.getfieldvalue('fill','none');
@@ -55,9 +55,9 @@
 
 	//check that each element has at least one flag
-	for(var i=0;i<md.mesh.numberofelements;i++)if((SIAflag[i] + SSAflag[i] + HOflag[i] + L1L2flag[i] + MLHOflag[i] + FSflag[i])==0)
+	for(var i=0;i<md.mesh.numberofelements;i++)if((SIAflag[i] + SSAflag[i] + HOflag[i] + L1L2flag[i] + MOLHOflag[i] + FSflag[i])==0)
 	throw Error("elements type not assigned, supported models are 'SIA','SSA','HO' and 'FS'");
 
 	//check that each element has only one flag
-	if (ArrayAnyAboveStrict(ArrayXPY(SIAflag,SSAflag,HOflag,L1L2flag,MLHOflag),1)){
+	if (ArrayAnyAboveStrict(ArrayXPY(SIAflag,SSAflag,HOflag,L1L2flag,MOLHOflag),1)){
 		console.log('setflowequation warning message: some elements have several types, higher order type is used for them')
 
@@ -71,5 +71,5 @@
 	//check that L1L2 is not coupled to any other model for now
 	if (ArrayAnyEqual(L1L2flag,1) & ArrayAnyEqual(ArrayOr(SIAflag,SSAflag,HOflag,FSflag),1)) throw Error('L1L2 cannot be coupled to any other model');
-	if (ArrayAnyEqual(MLHOflag,1) & ArrayAnyEqual(ArrayOr(SIAflag,SSAflag,HOflag,FSflag),1)) throw Error('MLHO cannot be coupled to any other model');
+	if (ArrayAnyEqual(MOLHOflag,1) & ArrayAnyEqual(ArrayOr(SIAflag,SSAflag,HOflag,FSflag),1)) throw Error('MOLHO cannot be coupled to any other model');
 
 	//Check that no HO or FS for 2d mesh
@@ -100,7 +100,7 @@
 	for(var i=0;i<pos.length;i++) for(var j=0;j<md.mesh.elements[0].length;j++) nodeonL1L2[md.mesh.elements[pos[i]][j]-1]=1;
 
-	nodeonMLHO=NewArrayFill(md.mesh.numberofvertices,0);
-	pos=ArrayFind(MLHOflag,1);
-	for(var i=0;i<pos.length;i++) for(var j=0;j<md.mesh.elements[0].length;j++) nodeonMLHO[md.mesh.elements[pos[i]][j]-1]=1;
+	nodeonMOLHO=NewArrayFill(md.mesh.numberofvertices,0);
+	pos=ArrayFind(MOLHOflag,1);
+	for(var i=0;i<pos.length;i++) for(var j=0;j<md.mesh.elements[0].length;j++) nodeonMOLHO[md.mesh.elements[pos[i]][j]-1]=1;
 
 	nodeonFS=NewArrayFill(md.mesh.numberofvertices,0);
@@ -262,5 +262,5 @@
 	pos=ArrayFind(SSAflag,1);for(var i=0;i<pos.length;i++)md.flowequation.element_equation[pos[i]]=2;
 	pos=ArrayFind(L1L2flag,1);for(var i=0;i<pos.length;i++)md.flowequation.element_equation[pos[i]]=3;
-	pos=ArrayFind(MLHOflag,1);for(var i=0;i<pos.length;i++)md.flowequation.element_equation[pos[i]]=4;
+	pos=ArrayFind(MOLHOflag,1);for(var i=0;i<pos.length;i++)md.flowequation.element_equation[pos[i]]=4;
 	pos=ArrayFind(HOflag,1);for(var i=0;i<pos.length;i++)md.flowequation.element_equation[pos[i]]=5;
 	pos=ArrayFind(FSflag,1);for(var i=0;i<pos.length;i++)md.flowequation.element_equation[pos[i]]=6;
@@ -281,5 +281,5 @@
 	pos=ArrayFind(nodeonSSA,1);for(var i=0;i<pos.length;i++)md.flowequation.vertex_equation[pos[i]]=2;
 	pos=ArrayFind(nodeonL1L2,1);for(var i=0;i<pos.length;i++)md.flowequation.vertex_equation[pos[i]]=3;
-	pos=ArrayFind(nodeonMLHO,1);for(var i=0;i<pos.length;i++)md.flowequation.vertex_equation[pos[i]]=4;
+	pos=ArrayFind(nodeonMOLHO,1);for(var i=0;i<pos.length;i++)md.flowequation.vertex_equation[pos[i]]=4;
 	pos=ArrayFind(nodeonHO,1);for(var i=0;i<pos.length;i++)md.flowequation.vertex_equation[pos[i]]=5;
 	pos=ArrayFind(nodeonFS,1);for(var i=0;i<pos.length;i++)md.flowequation.vertex_equation[pos[i]]=6;
@@ -301,5 +301,5 @@
 	md.flowequation.isSSA  = ArrayAnyEqual(md.flowequation.element_equation,2);
 	md.flowequation.isL1L2 = ArrayAnyEqual(md.flowequation.element_equation,3);
-	md.flowequation.isMLHO = ArrayAnyEqual(md.flowequation.element_equation,4);
+	md.flowequation.isMOLHO = ArrayAnyEqual(md.flowequation.element_equation,4);
 	md.flowequation.isHO   = ArrayAnyEqual(md.flowequation.element_equation,5);
 	md.flowequation.isFS   = ArrayAnyEqual(md.flowequation.element_equation,6);
@@ -3,5 +3,5 @@
 //
 //   This routine works like plotmodel: it works with an even number of inputs
-//   'SIA','SSA','L1L2','MLHO','HO','FS' and 'fill' are the possible options
+//   'SIA','SSA','L1L2','MOLHO','HO','FS' and 'fill' are the possible options
 //   that must be followed by the corresponding exp file or flags list
 //   It can either be a domain file (argus type, .exp extension), or an array of element flags. 
@@ -11,5 +11,5 @@
 //   a string 'all' will be considered as the entire domain
 //   You can specify the type of coupling, 'penalties' or 'tiling', to use with the input 'coupling'
-//   NB: L1L2 and MLHO cannot currently be coupled to any other ice flow model
+//   NB: L1L2 and MOLHO cannot currently be coupled to any other ice flow model
 //
 //   Usage:
